@@ -1,6 +1,6 @@
 /*
 Gwenview: an image viewer
-Copyright 2007 Aurélien Gâteau <aurelien.gateau@free.fr>
+Copyright 2007 Aurélien Gâteau <agateau@kde.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -22,13 +22,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #define ABSTRACTCONTEXTMANAGERITEM_H
 
 // Qt
-#include <QObject>
+#include <QWidget>
 
 
 namespace Gwenview {
 
 class ContextManager;
-class SideBar;
 
 struct AbstractContextManagerItemPrivate;
 class AbstractContextManagerItem : public QObject {
@@ -37,10 +36,13 @@ public:
 	AbstractContextManagerItem(ContextManager*);
 	virtual ~AbstractContextManagerItem();
 
-	virtual void setSideBar(SideBar*) = 0;
+	QWidget* widget() const;
 
 	ContextManager* contextManager() const;
 
+protected:
+	void setWidget(QWidget* widget);
+
 private:
 	AbstractContextManagerItemPrivate * const d;
 };
